Index: configs/features.conf.sample
===================================================================
--- configs/features.conf.sample	(revision 60916)
+++ configs/features.conf.sample	(working copy)
@@ -8,6 +8,8 @@
 				; numeric, as Asterisk starts from the start position
 				; and increments with one for the next parked call.
 context => parkedcalls		; Which context parked calls are in
+;parkdialoptions => TtWwKk     ; What dial options will be (globally) used when dialing back after a timeout (default is none)
+;parkdialtimeout => 30         ; Global dialing timeout when dialing back from a parking (default is 30 seconds)
 ;parkingtime => 45		; Number of seconds a call can be parked for 
 				; (default is 45 seconds)
 ;courtesytone = beep		; Sound file to play to the parked caller 
Index: res/res_features.c
===================================================================
--- res/res_features.c	(revision 60916)
+++ res/res_features.c	(working copy)
@@ -89,6 +89,9 @@
 static int parking_start;                                  /*!< First available extension for parking */
 static int parking_stop;                                   /*!< Last available extension for parking */
 
+static char parking_dial_opt[AST_MAX_EXTENSION];           /*!< Dial options when dialing back from a parking */
+static int parking_dial_timeout;                           /*!< Global timeout when dialing back from a parking */
+
 static char courtesytone[256];                             /*!< Courtesy tone */
 static int parkedplay = 0;                                 /*!< Who to play the courtesy tone to */
 static char xfersound[256];                                /*!< Call transfer sound */
@@ -1696,7 +1699,7 @@
 					}
 					if (con) {
 						char returnexten[AST_MAX_EXTENSION];
-						snprintf(returnexten, sizeof(returnexten), "%s||t", peername);
+						snprintf(returnexten, sizeof(returnexten), "%s|%d|%s", peername, parking_dial_timeout, parking_dial_opt);
 						ast_add_extension2(con, 1, peername, 1, NULL, NULL, "Dial", strdup(returnexten), ast_free, registrar);
 					}
 					if (comebacktoorigin) { 
@@ -2025,6 +2028,8 @@
 	ast_cli(fd,"%-20s:	%s\n", "Parking extension", parking_ext);
 	ast_cli(fd,"%-20s:	%s\n", "Parking context", parking_con);
 	ast_cli(fd,"%-20s:	%d-%d\n", "Parked call extensions", parking_start, parking_stop);
+	ast_cli(fd,"%-20s:	%s\n", "Dialback options", parking_dial_opt);
+	ast_cli(fd,"%-20s:	%d\n", "Dialback timeout", parking_dial_timeout);
 	ast_cli(fd,"\n");
 	
 	return RESULT_SUCCESS;
@@ -2243,6 +2248,8 @@
 	/* Reset to defaults */
 	strcpy(parking_con, "parkedcalls");
 	strcpy(parking_con_dial, "park-dial");
+	strcpy(parking_dial_opt, "");
+	parking_dial_timeout = 30;
 	strcpy(parking_ext, "700");
 	strcpy(pickup_ext, "*8");
 	strcpy(parkmohclass, "default");
@@ -2316,6 +2323,10 @@
 				ast_log(LOG_WARNING, "%s is not a valid featuredigittimeout\n", var->value);
 				featuredigittimeout = DEFAULT_FEATURE_DIGIT_TIMEOUT;
 			}
+		} else if (!strcasecmp(var->name, "parkdialtimeout")) {
+			if ((sscanf(var->value, "%d", &parking_dial_timeout) != 1) || (parking_dial_timeout < 1)) {
+				ast_log(LOG_WARNING, "%s is not a valid parkdialtimeout\n", var->value);
+			}
 		} else if (!strcasecmp(var->name, "atxfernoanswertimeout")) {
 			if ((sscanf(var->value, "%d", &atxfernoanswertimeout) != 1) || (atxfernoanswertimeout < 1)) {
 				ast_log(LOG_WARNING, "%s is not a valid atxfernoanswertimeout\n", var->value);
@@ -2341,6 +2352,8 @@
 			comebacktoorigin = ast_true(var->value);
 		} else if (!strcasecmp(var->name, "parkedmusicclass")) {
 			ast_copy_string(parkmohclass, var->value, sizeof(parkmohclass));
+		} else if (!strcasecmp(var->name, "parkdialoptions")) {
+			ast_copy_string(parking_dial_opt, var->value, sizeof(parking_dial_opt));
 		}
 	}
 
